﻿using Hotline.FlowEngine.Notifies;
using Hotline.Orders;
using Hotline.Settings;
using Hotline.Share.Enums.Order;
using MediatR;
using XF.Domain.Exceptions;

namespace Hotline.Application.Handlers.FlowEngine;

public class NextStepHandler : INotificationHandler<NextStepNotify>
{
    private readonly IOrderRepository _orderRepository;

    public NextStepHandler(IOrderRepository orderRepository)
    {
        _orderRepository = orderRepository;
    }

    /// <summary>Handles a notification</summary>
    /// <param name="notification">The notification</param>
    /// <param name="cancellationToken">Cancellation token</param>
    public async Task Handle(NextStepNotify notification, CancellationToken cancellationToken)
    {
        var workflow = notification.Workflow;
        var data = notification.Dto;
        switch (workflow.ModuleCode)
        {
            case WorkflowModuleConsts.Order:
                var order = await _orderRepository.GetAsync(d => d.WorkflowId == workflow.Id, cancellationToken);
                if (order == null)
                    throw new UserFriendlyException($"工单审批流程Id无效, workflowId: {workflow.Id}", "无效流程编号");
                order.Assign(notification.FlowAssignType, data.Handlers);

                //todo business logic

                if (order.Status is EOrderStatus.Filed) return;
                //1.如果order未处于会签中，则判断是否发起会签（isstartCountersign） 2.如果处于会签中，则判断会签是否结束（isCountersignEnd）
                if (order.Status is EOrderStatus.Countersigning && notification.IsCountersignEnd)
                {
                    order.Status = EOrderStatus.WaitForSign;
                }
                else if (order.Status is not EOrderStatus.Countersigning && notification.IsCountersignStart)
                {
                    order.Status = EOrderStatus.Countersigning;
                }

                order.CurrentStepTime = workflow.CurrentStepTime;
                order.CurrentStepName = workflow.CurrentStepName;
                break;
        }
    }
}