﻿using Hotline.CallCenter.BlackLists;
using Hotline.FlowEngine.Definitions;
using Hotline.Identity.Roles;
using Hotline.Share.Dtos.CallCenter;
using Hotline.Share.Dtos.FlowEngine;
using Hotline.Share.Dtos.Roles;
using Hotline.Share.Dtos.Users;
using Hotline.Users;
using Mapster;

namespace Hotline.Application.Mappers
{
    public class MapperConfigs : IRegister
    {
        public void Register(TypeAdapterConfig config)
        {
            config.NewConfig<AddBlacklistDto, Blacklist>()
                .Ignore(d => d.Expired)
                .AfterMapping((s, t) => t.InitExpired());

            config.NewConfig<AddUserDto, User>()
                .Map(d => d.Name, x => x.Name ?? x.UserName);

            config.NewConfig<User, UserDto>()
                .Map(d => d.UserName, x => x.Account.UserName)
                .Map(d => d.OrgName, x => x.Organization.OrgName)
                .Map(d => d.Roles, x => string.Join(',', x.Account.Roles.Select(d => d.DisplayName)))
                .Map(d => d.State, x => x.IsDeleted ? "已删除" : "正常")
                .IgnoreIf((s, d) => s.Account == null, d => d.UserName)
                .IgnoreIf((s, d) => s.Account == null, d => d.Roles)
                ;

            config.NewConfig<Role, RoleDto>()
                .Map(d => d.AccountIds, x => x.Accounts.Select(d => d.Id))
                .Map(d => d.State, x => x.IsDeleted ? "已删除" : "正常");

            #region workflow

            config.NewConfig<UpdateDefinitionDto, Definition>()
                .Ignore(d => d.Id);



            #endregion
        }
    }
}
