﻿using Hotline.Settings;
using Hotline.Share.Enums.Settings;
using Hotline.Users;
using Microsoft.Extensions.DependencyInjection;
using XF.Domain.Authentications;
using XF.Domain.Dependency;
using XF.Domain.Entities;

namespace Hotline.Repository.SqlSugar.DataPermissions;

public class DataPermissionManager : IDataPermissionManager, IScopeDependency
{
    private readonly IServiceScopeFactory _serviceScopeFactory;
    private readonly ISessionContext _sessionContext;

    public DataPermissionManager(IServiceScopeFactory serviceScopeFactory, ISessionContext sessionContext)
    {
        _serviceScopeFactory = serviceScopeFactory;
        _sessionContext = sessionContext;
    }

    public DataPermissionScheme GetQueryFilter<TEntity>(ISessionContext sessionContext) where TEntity : class, IEntity<string>, IDataPermission, new()
    {
        EAuthorityType? queryFilter = GetCurrentQueryFilter(sessionContext.Roles, typeof(TEntity).Name);
        if (queryFilter == null)
        {
            
            //todo 未配置数据查询权限处理方案
            //TODO 不处理
        }

        //全部
        if (queryFilter == EAuthorityType.All)
            return new DataPermissionScheme(EAuthorityType.All);

        //本部
        if (queryFilter == EAuthorityType.Org)
            return new DataPermissionScheme(EAuthorityType.Org);

        //本部及本部以下
        if (queryFilter == EAuthorityType.OrgAndBelow)
        {
            //todo 查询对应部门编码
            return new DataPermissionScheme(EAuthorityType.OrgAndBelow, "");
        }

        //创建人
        if (queryFilter == EAuthorityType.Create)
            return new DataPermissionScheme(EAuthorityType.Create);

        throw new NotImplementedException();
    }

    public (string orgId,string departmentCode, string creatorId, string? areaId) GetDataPermissionOptions()
    {
        using var scope = _serviceScopeFactory.CreateScope();
        var userRepository = scope.ServiceProvider.GetService<IUserRepository>();
        var user = userRepository!.GetAsync(_sessionContext.RequiredUserId).Result;
        if (!string.IsNullOrEmpty(user!.OrgId))
        {
            var orgRepository = scope.ServiceProvider.GetService<ISystemOrganizeRepository>();
            var org = orgRepository!.GetAsync(user!.OrgId).Result;

            return (org!.Id, org.OrgCode, _sessionContext.RequiredUserId, org.OrgCode);
        }
        return ("", "", _sessionContext.RequiredUserId, "");
    }

    private EAuthorityType? GetCurrentQueryFilter(string[] roles, string entityName)
    {
        using var scope = _serviceScopeFactory.CreateScope();
        var systemDataTableRepository = scope.ServiceProvider.GetService<ISystemDataTableRepository>();
        var systemDataAuthorityRepository = scope.ServiceProvider.GetService<ISystemDataAuthorityRepository>();

        ////查询对应表配置
        var tableModel = systemDataTableRepository!.GetAsync(x => x.EntityName == entityName).Result;
        ////查询表对应最高数据权限
        var auth = systemDataAuthorityRepository!.GetMyTopDataAuth(roles, tableModel!.Id);
        return auth;
    }
}