﻿using Hotline.Share.Enums.FlowEngine;
using XF.Domain.Entities;

namespace Hotline.FlowEngine.Definitions;

/// <summary>
/// 模板定义节点
/// </summary>
public class StepDefine : StepBasic
{
    public List<NextStepDefine> NextSteps { get; set; }
    
    /// <summary>
    /// 是否发起会签
    /// </summary>
    /// <param name="handlerCount">下一节点办理人数量</param>
    /// <returns></returns>
    public bool IsStartCountersign(int handlerCount)
    {
        //需求：按角色指派默认不发起会签
        if (HandlerType is EHandlerType.Role) return false;
        return handlerCount > 1;
    }

    public (EFlowAssignType assignType, List<string> handlers) GetFlowAssignMode(List<string> handlers)
    {
        switch (HandlerType)
        {
            case EHandlerType.Role:
                return handlers.Any() ? (EFlowAssignType.User, handlers) : (EFlowAssignType.Role, HandlerClassifies);
            case EHandlerType.OrgLevel:
            case EHandlerType.OrgType:
            case EHandlerType.AssignOrg:
                return (EFlowAssignType.Org, handlers);
            case EHandlerType.AssignUser:
                return (EFlowAssignType.User, handlers);
            default:
                throw new ArgumentOutOfRangeException();
        }
    }
}