﻿using Hotline.Share.Enums.FlowEngine;
using SqlSugar;
using XF.Domain.Repository;

namespace Hotline.FlowEngine.Workflows;

public class StepBasicEntity : CreationEntity
{
    public string WorkflowId { get; set; }

    public string Name { get; set; }

    /// <summary>
    /// 模板内唯一
    /// </summary>
    public string Code { get; set; }

    public EStepType StepType { get; init; }

    /// <summary>
    /// 办理人类型
    /// </summary>
    public EHandlerType HandlerType { get; set; }

    /// <summary>
    /// 审批者分类（或是直接保存处理者）
    /// <example>
    /// 根据类型可能为：roles, depLevels, depTypes, depCodes, userIds
    /// </example>
    /// </summary>
    [SugarColumn(ColumnDataType = "varchar(1000)", IsJson = true)]
    public List<string> HandlerClassifies { get; set; } = new();

    /// <summary>
    /// 当前环节会签模式
    /// </summary>
    public ECountersignMode CountersignMode { get; set; }

    #region 办理参数

    /// <summary>
    /// (下一节点办理人)根据审批者类型不同，此字段为不同内容
    /// <example>
    /// 部门等级/分类为：orgCodes, 角色为：userIds
    /// </example>
    /// </summary>
    [SugarColumn(ColumnDataType = "varchar(2000)", IsJson = true)]
    public List<string> NextHandlers { get; set; }

    /// <summary>
    /// 下一节点主办，(NextHandlers其中一个, 如果不是会签则只有一个)
    /// </summary>
    public string NextMainHandler { get; set; }

    /// <summary>
    /// 下一节点code
    /// </summary>
    public string NextStepCode { get; set; }

    /// <summary>
    /// 是否短信通知
    /// </summary>
    public bool AcceptSms { get; set; }

    /// <summary>
    /// 办理意见
    /// </summary>
    [SugarColumn(Length = 2000)]
    public string Opinion { get; set; }

    /// <summary>
    /// 附件
    /// </summary>
    [SugarColumn(ColumnDataType = "varchar(1000)", IsJson = true)]
    public List<string> Additions { get; set; }

    #endregion

    #region 办理

    /// <summary>
    /// 办理人
    /// </summary>
    [SugarColumn(IsNullable = true)]
    public string? UserId { get; set; }

    [SugarColumn(IsNullable = true)]
    public string? UserName { get; set; }

    /// <summary>
    /// 办理人部门code
    /// </summary>
    [SugarColumn(IsNullable = true)]
    public string? OrgCode { get; set; }

    [SugarColumn(IsNullable = true)]
    public string? OrgName { get; set; }

    /// <summary>
    /// 办理完成时间
    /// </summary>
    public DateTime? CompleteTime { get; set; }

    #endregion

    #region 接办

    /// <summary>
    /// 接办人
    /// </summary>
    [SugarColumn(IsNullable = true)]
    public string? AcceptUserId { get; set; }

    [SugarColumn(IsNullable = true)]
    public string? AcceptUserName { get; set; }

    /// <summary>
    /// 接办时间
    /// </summary>
    public DateTime? AcceptTime { get; set; }

    #endregion
    
}