﻿using Hotline.Share.Enums.Order;
using Hotline.Users;
using SqlSugar;
using XF.Domain.Repository;

namespace Hotline.Orders
{
    /// <summary>
    /// 工单
    /// </summary>
    public partial class Order : PositionWorkflowEntity
    {
        #region 来电信息

        /// <summary>
        /// 来源渠道
        /// </summary>
        public EChannel Channel { get; set; }

        /// <summary>
        /// 接线员工
        /// </summary>
        public string EmployeeId { get; set; }

        /// <summary>
        /// 来电号码
        /// </summary>
        public string? FromPhone { get; set; }

        /// <summary>
        /// 转接号码（转接来源）
        /// </summary>
        public string? TransferPhone { get; set; }

        /// <summary>
        /// 来电/信人姓名
        /// </summary>
        public string FromName { get; set; }

        /// <summary>
        /// 来电/信人性别
        /// </summary>
        public EGender FromGender { get; set; }

        /// <summary>
        /// 来电/信人身份
        /// </summary>
        public ECitizenStatus FromStatus { get; set; }

        /// <summary>
        /// 证件类型
        /// </summary>
        public ELicenceType? Licence { get; set; }

        /// <summary>
        /// 证件号码
        /// </summary>
        public string? LicenceNo { get; set; }

        /// <summary>
        /// 年龄段
        /// </summary>
        public EAgeRange? AgeRange { get; set; }

        /// <summary>
        /// 联系电话
        /// </summary>
        [SugarColumn(ColumnDescription = "联系电话", IsNullable = true)]
        public string? Contact { get; set; }

        [SugarColumn(ColumnDescription = "联系电话脱敏", IsNullable = true)]
        public string? ContactMask { get; set; }

        /// <summary>
        /// 是否接受短信，勾选校验手机号
        /// </summary>
        public bool AcceptSms { get; set; }

        /// <summary>
        /// 是否需要联系
        /// </summary>
        public bool NeedContact { get; set; }

        /// <summary>
        /// 工作单位(当“来电/信人身份”为“企业”时必填，其他情况非必填)
        /// </summary>
        [SugarColumn(ColumnDescription = "工作单位", IsNullable = true)]
        public string? Company { get; set; }

        /// <summary>
        /// 接线员(服务人)
        /// </summary>
        [Navigate(NavigateType.OneToOne, nameof(EmployeeId))]
        public User Employee { get; set; }

        #endregion

        #region 诉求信息

        /// <summary>
        /// 工单编码（202201010001）
        /// </summary>
        public string No { get; set; }

        /// <summary>
        /// 工单类型
        /// </summary>
        public EOrderType OrderType { get; set; }

        /// <summary>
        /// 受理类型
        /// </summary>
        public EAcceptType AcceptType { get; set; }

        /// <summary>
        /// 紧急程度
        /// </summary>
        public EEmergencyLevel EmergencyLevel { get; set; } = EEmergencyLevel.Normal;

        public string Title { get; set; }

        /// <summary>
        /// 热点
        /// </summary>
        public string HotspotId { get; set; }
        public string Hotspot { get; set; }
        public string HotspotSpliceName { get; set; }

        /// <summary>
        /// 事发时间
        /// </summary>
        public DateTime? IncidentTime { get; set; }

        /// <summary>
        /// 重复工单
        /// </summary>
        [SugarColumn(ColumnDescription = "重复工单Id", IsNullable = true)]
        public string? DuplicateId { get; set; }

        [SugarColumn(ColumnDescription = "重复工单", IsNullable = true)]
        public string? DuplicateName { get; set; }

        /// <summary>
        /// 推送分类
        /// </summary>
        public EPushType PushType { get; set; }

        /// <summary>
        /// 附件
        /// </summary>
        [SugarColumn(ColumnDataType = "varchar(2000)", IsJson = true)]
        public List<string> Additions { get; set; } = new();

        /// <summary>
        /// 诉求内容
        /// </summary>
        public string Content { get; set; }

        #endregion
        
        /// <summary>
        /// 当前节点名称
        /// </summary>
        public string CurrentStepName { get; set; }

        /// <summary>
        /// 到达当前节点时间
        /// </summary>
        public DateTime CurrentStepTime { get; set; }

        /// <summary>
        /// 工单状态
        /// </summary>
        public EOrderStatus Status { get; set; }

        /// <summary>
        /// 开始时间
        /// </summary>
        public DateTime? StartTime { get; set; }

        /// <summary>
        /// 过期时间
        /// </summary>
        public DateTime? ExpiredTime { get; set; }

        /// <summary>
        /// 过期状态
        /// </summary>
        public EExpiredStatus ExpiredStatus { get; set; }
    }

    public enum EExpiredStatus
    {
        /// <summary>
        /// 正常状态（未超期）
        /// </summary>
        Normal = 0,

        /// <summary>
        /// 即将超期
        /// </summary>
        GoingToExpired = 1,

        /// <summary>
        /// 已超期
        /// </summary>
        Expired = 2,
    }

    /// <summary>
    /// 渠道为电话时存在字段
    /// </summary>
    public partial class Order
    {
        /// <summary>
        /// 工单扩展信息（12315-投诉）
        /// </summary>
        [Navigate(NavigateType.OneToOne, nameof(Id))]
        public OrderComplain OrderComplain { get; set; }
    }
}
