﻿using XF.Domain.Cache;
using XF.Domain.Exceptions;
using XF.Domain.Extensions;

namespace Hotline.Orders;

public class OrderDomainService : IOrderDomainService
{
    private const string OrderNoPrefix = "OrderNo:";
    private readonly IOrderRepository _orderRepository;
    private readonly ITypedCache<int> _cacheOrderNo;

    public OrderDomainService(
        IOrderRepository orderRepository,
        ITypedCache<int> cacheOrderNo)
    {
        _orderRepository = orderRepository;
        _cacheOrderNo = cacheOrderNo;
    }

    public async Task<string> AddAsync(Order order, CancellationToken cancellationToken)
    {
        if (!string.IsNullOrEmpty(order.Contact))
            order.ContactMask = order.Contact.MaskPhoneNumber();

        order.No = GenerateNewOrderNo();

        return await _orderRepository.AddAsync(order, cancellationToken);
    }

    private string GenerateNewOrderNo()
    {
        var today = DateTime.Today;
        var cacheKey = $"{OrderNoPrefix}{today:yyyyMMdd}";
        var count = _cacheOrderNo.GetOrAdd(cacheKey, f =>
        {
            var todayOrderCount = _orderRepository.Queryable(true)
                .CountAsync(d => d.CreationTime.Date == today.Date)
                .GetAwaiter()
                .GetResult();
            return todayOrderCount;
        }, ExpireMode.Absolute, TimeSpan.FromDays(1));
        count += 1;
        var no = GenerateOrderNo(today, count);
        _cacheOrderNo.Update(cacheKey, d => count);
        return no;
    }

    private string GenerateOrderNo(DateTime today, int count)
    {
        return $"{today:yyyyMMdd}{count.ToString("000000")}";
    }
}
